import 'package:flutter/material.dart';
import 'package:miapp_flutter/src/pages/articles_page.dart';
import '../../controllers/CategoriaController.dart';
import '../../models/CategoriaModel.dart';

class CategoryListWidget extends StatefulWidget {
  @override
  _CategoryWidgetState createState() => _CategoryWidgetState();
}

class _CategoryWidgetState extends State<CategoryListWidget> {
  final CategoryController _categoryCtrl = CategoryController();

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Padding(
        padding: const EdgeInsets.all(16.0),
        child: FutureBuilder<Map<String, dynamic>>(
          future: _categoryCtrl.getCategories(),
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              if (snapshot.data!['ok']) {
                if (snapshot.data!['data'] != null && (snapshot.data!['data'] as List).isNotEmpty) {
                  List<CategoriaModel> categories = snapshot.data!['data'];
                  return ListView.builder(
                    itemBuilder: (BuildContext context, int index) {
                      final category = categories[index];
                      return Card(
                        child: ListTile(
                          title: Text(category.name ?? 'No Name'),
                          leading: const Icon(Icons.touch_app),
                          onTap: () {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) => ArticlePage(categoryId: category.id),
                              ),
                            );
                          },
                        ),
                      );
                    },
                    itemCount: categories.length,
                  );
                } else {
                  return Center(child: Text("No se encontraron categorías"));
                }
              } else {
                return Center(child: Text("Error: ${snapshot.data!['message']}"));
              }
            } else if (snapshot.hasError) {
              return Center(child: Text("Error: ${snapshot.error.toString()}"));
            } else {
              return const Center(
                child: CircularProgressIndicator(),
              );
            }
          },
        ),
      ),
    );
  }
}
